# Algora Labs

**[Algora Labs](https://algoralabs.com/)** is a strategy development platform for trading. Build, test and launch
complex trading strategies in minutes instead of days or weeks. We manage your environment, so you can focus more time
on building profitable strategies.

## Features

* Create complex, multi-asset class strategies with instruments of any type
* Track position- and portfolio- level risks
* Manage cash payments and slippage
* Design and develop custom instruments
* Integrate external data and pricers without exposing any proprietary logic

## SDK

The [algora-sdk](https://pypi.org/project/algora-sdk/) allows users to programmatically access our APIs and data.

> **Note**\
> Our quantitative finance framework (strategy development and backtesting) is only available through our platform

### Installation

Set the following environment variables for your username and password for [Algora Labs](https://trade.algoralabs.com/).

```text
ALGORA_USER=<username>
ALGORA_PWD=<password>
```

## Help

If you need any help or have feedback, please email us at [support@algoralabs.com](mailto:support@algoralabs.com).
